# Naming Conventions

The source files in this directory are named after the corresponding piece
of the TOAST python package.  For example::

    toast_tod_simnoise.cpp

Has noise simulation tools related to the toast.tod module.
